@@ -18,7 +18,7 @@ class Nhentai(object):
         -------
         None
         """
-        if api_key is '':
+        if api_key == '':
             self.api_key = None
         else:
             self.api_key = api_key
@@ -194,3 +194,4 @@ class Nhentai(object):
             raise ValueError('Request failed')
 
         return parser(data.json())
+        
