@@ -40,7 +40,7 @@ class Pururin(object):
         api_key : str
             scathach.dev API key (optional)
         """
-        if api_key is '':
+        if api_key == '':
             self.api_key = None
         else:
             self.api_key = api_key
